from pprint import pp
from colorama import Style, init, Back, Fore

init(autoreset=True)

class Notifications:

    FUNC_NOT_MAPPED = f"The function you've tried run is not mapped in Vialactea pack yet. Follow https://pypi.org/project/vialactea/ for more features."
    FUNC_UNDER_MAINTENANCE = f'{Fore.YELLOW}{Back.BLACK} Warning! This function is under maintenance and should problaly change on a upcomming update'







